@@ -1,3 +1,5 @@
+use more_asserts::assert_ge;
+
 use crate::bindings::kernel;
 use crate::RgbaSurface;
 
@@ -21,7 +23,7 @@ pub fn compress_blocks(settings: EncodeSettings, surface: &RgbaSurface) -> Vec<u
 }
 
 pub fn compress_blocks_into(settings: EncodeSettings, surface: &RgbaSurface, blocks: &mut [u8]) {
-    assert_eq!(
+    assert_ge!(
         blocks.len(),
         calc_output_size(surface.width, surface.height)
     );
